@@ -27,34 +27,7 @@ func (ui *UI) ListDevices(getter device.DevicesInfoGetter) error {
 		return err
 	}
 
-	ui.table.SetCell(0, 0, tview.NewTableCell("Device name").SetSelectable(false))
-	ui.table.SetCell(0, 1, tview.NewTableCell("Size").SetSelectable(false))
-	ui.table.SetCell(0, 2, tview.NewTableCell("Used").SetSelectable(false))
-	ui.table.SetCell(0, 3, tview.NewTableCell("Used part").SetSelectable(false))
-	ui.table.SetCell(0, 4, tview.NewTableCell("Free").SetSelectable(false))
-	ui.table.SetCell(0, 5, tview.NewTableCell("Mount point").SetSelectable(false))
-
-	var textColor, sizeColor string
-	if ui.UseColors {
-		textColor = "[#3498db:-:b]"
-		sizeColor = "[#edb20a:-:b]"
-	} else {
-		textColor = "[white:-:b]"
-		sizeColor = "[white:-:b]"
-	}
-
-	for i, device := range ui.devices {
-		ui.table.SetCell(i+1, 0, tview.NewTableCell(textColor+device.Name).SetReference(ui.devices[i]))
-		ui.table.SetCell(i+1, 1, tview.NewTableCell(ui.formatSize(device.Size, false, true)))
-		ui.table.SetCell(i+1, 2, tview.NewTableCell(sizeColor+ui.formatSize(device.Size-device.Free, false, true)))
-		ui.table.SetCell(i+1, 3, tview.NewTableCell(getDeviceUsagePart(device)))
-		ui.table.SetCell(i+1, 4, tview.NewTableCell(ui.formatSize(device.Free, false, true)))
-		ui.table.SetCell(i+1, 5, tview.NewTableCell(textColor+device.MountPoint))
-	}
-
-	ui.table.Select(1, 0)
-	ui.footerLabel.SetText("")
-	ui.table.SetSelectedFunc(ui.deviceItemSelected)
+	ui.showDevices()
 
 	return nil
 }
